﻿-- SpartanMoneyDisplay --
-------------------
-- Global variables
-------------------

SpartanMoneyDisplay_DEFAULT_ON       = 1;
SpartanMoneyDisplay_DEFAULT_LOCKED   = nil;
SpartanMoneyDisplay_DEFAULT_ALPHA    = 255;
SpartanMoneyDisplay_DEFAULT_BORDER   = 1;
SpartanMoneyDisplay_DEFAULT_dispX    = GetScreenWidth()/2;
SpartanMoneyDisplay_DEFAULT_dispY    = GetScreenHeight()-50;
SpartanMoneyDisplay_DEFAULT_CASHFLOW = { };
SpartanMoneyDisplay_DEFAULT_DEFCF    = { on = false; cash = nil; }
SpartanMoneyDisplay_Gold      = 0;
SpartanMoneyDisplay_Silver    = 0;
SpartanMoneyDisplay_Copper    = 0;
SpartanMoneyDisplay_LastShown = nil;
SpartanMoneyDisplay_Passive   = nil;
SpartanMoneyDisplay_PlayerName = UnitName("player");

-------------------
-- OnLoad Function
-------------------

function SMD_OnLoad()

        -- Set Variables if required
        SpartanMoneyDisplay_SetVariables();

        -- Register the events that need to be watched
        this:RegisterEvent("VARIABLES_LOADED");

        -- Register the slash command
        SlashCmdList["SPARTANMONEYDISPLAY"] = function(msg)
          SpartanMoneyDisplay_SlashCommand(msg);
        end;
        SLASH_SPARTANMONEYDISPLAY1 = "/SpartanMoney";

       if( DEFAULT_CHAT_FRAME ) then
         DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay v1 loaded");
       end
         UIErrorsFrame:AddMessage("SpartanMoneyDisplay AddOn loaded", 1.0, 1.0, 1.0, 1.0, UIERRORS_HOLD_TIME);
end

--------------------
-- OnEvent Event
--------------------

function SMD_OnEvent()

        -- If the settings are loaded then update the display
        if(event == "VARIABLES_LOADED") then

                if (strsub(tostring(SpartanMoneyDisplaySettings.cashflow),1,7) ~= "table: ") then
                  SpartanMoneyDisplaySettings.cashflow = SpartanMoneyDisplay_DEFAULT_CASHFLOW;
                end;

                if (not SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName]) then
                  SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName] = SpartanMoneyDisplay_DEFAULT_DEFCF;
                end;

                SMD_Frame:ClearAllPoints();
                SMD_Frame:SetPoint("BOTTOMLEFT", "UIParent", "BOTTOMLEFT", SpartanMoneyDisplaySettings.dispX, SpartanMoneyDisplaySettings.dispY);

                SpartanMoneyDisplay_Update();
        end

end

--------------------
-- Set Variables
--------------------

function SpartanMoneyDisplay_SetVariables()

        if not (SpartanMoneyDisplaySettings) then
                -- Default Settings
                SpartanMoneyDisplaySettings = { };
                SpartanMoneyDisplaySettings.on       = SpartanMoneyDisplay_DEFAULT_ON;
                SpartanMoneyDisplaySettings.locked   = SpartanMoneyDisplay_DEFAULT_LOCKED;
                SpartanMoneyDisplaySettings.alpha    = SpartanMoneyDisplay_DEFAULT_ALPHA;
                SpartanMoneyDisplaySettings.border   = SpartanMoneyDisplay_DEFAULT_BORDER;
                SpartanMoneyDisplaySettings.dispX    = SpartanMoneyDisplay_DEFAULT_dispX;
                SpartanMoneyDisplaySettings.dispY    = SpartanMoneyDisplay_DEFAULT_dispY;
                SpartanMoneyDisplaySettings.cashflow = SpartanMoneyDisplay_DEFAULT_CASHFLOW;
        end
end

function SpartanMoneyDisplay_ResetVariables()

        -- Reset Settings
        SpartanMoneyDisplaySettings = { };
        SpartanMoneyDisplaySettings.on       = SpartanMoneyDisplay_DEFAULT_ON;
        SpartanMoneyDisplaySettings.locked   = SpartanMoneyDisplay_DEFAULT_LOCKED;
        SpartanMoneyDisplaySettings.alpha    = SpartanMoneyDisplay_DEFAULT_ALPHA;
        SpartanMoneyDisplaySettings.border   = SpartanMoneyDisplay_DEFAULT_BORDER;
        SpartanMoneyDisplaySettings.dispX    = SpartanMoneyDisplay_DEFAULT_dispX;
        SpartanMoneyDisplaySettings.dispY    = SpartanMoneyDisplay_DEFAULT_dispY;
        SpartanMoneyDisplaySettings.cashflow = SpartanMoneyDisplay_DEFAULT_CASHFLOW;
end

--------------------
-- OnUpdate Function
--------------------

function SMD_OnUpdate(arg1)
        local cf = GetMoney();

        if (SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].on) then
          cf = cf - SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].cash;
        end

        if ((cf < 0) and (SpartanMoneyDisplay_Passive == nil)) then
          SpartanMoneyDisplay_Passive = 1;
          SMD_GoldText:SetTextColor  (1.0,0.0,0.0);
          SMD_SilverText:SetTextColor(1.0,0.0,0.0);
          SMD_CopperText:SetTextColor(1.0,0.0,0.0);
        end;
        if ((cf >= 0) and (SpartanMoneyDisplay_Passive == 1)) then
          SpartanMoneyDisplay_Passive = nil;
          SMD_GoldText:SetTextColor  (1.0,0.8196,0.0);
          SMD_SilverText:SetTextColor(1.0,0.8196,0.0);
          SMD_CopperText:SetTextColor(1.0,0.8196,0.0);
        end;

        if (cf < 0) then
          cf = -cf;
        end;

        if (SpartanMoneyDisplay_LastShown ~= cf) then
          SpartanMoneyDisplay_LastShown = cf;
          SpartanMoneyDisplay_Gold   = floor(cf/10000);
          SpartanMoneyDisplay_Silver = floor((cf-SpartanMoneyDisplay_Gold*10000)/100);
          SpartanMoneyDisplay_Copper = cf-SpartanMoneyDisplay_Gold*10000-SpartanMoneyDisplay_Silver*100;
        end;

        SMD_GoldText:SetText  (""..(SpartanMoneyDisplay_Gold  ).."    ");
        SMD_SilverText:SetText(""..(SpartanMoneyDisplay_Silver).."    ");
        SMD_CopperText:SetText(""..(SpartanMoneyDisplay_Copper).."    ");
end

-------------------------
-- Cashflow Function
-------------------------

function SMD_OnMiddleClick()
        SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName] = { on = true; cash = GetMoney(); }
end

function SMD_OnMouseWheel(arg1)
        if (arg1 < 0) then
          SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].on = true;
          if (SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].cash == nil) then
            SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].cash = GetMoney();
          end;
        else
          SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].on = false;
        end;
end

--------------------
-- Slash Commands
--------------------

function SpartanMoneyDisplay_SlashCommand(msg)

        -- Check the command
        if(msg) then
                local command = string.lower(msg);
                
                if(command == "show") then
                        SpartanMoneyDisplaySettings.on = 1;
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Show");

                elseif(command == "hide") then
                        SpartanMoneyDisplaySettings.on = nil;
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Hide");

                elseif(command == "reset") then
                        SpartanMoneyDisplay_ResetVariables();
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Reset");

                elseif(command == "lock") then
                        SpartanMoneyDisplaySettings.locked = 1;
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Locked");

                elseif(command == "unlock") then
                        SpartanMoneyDisplaySettings.locked = nil;
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Unlocked");

                elseif(command == "hideborder") then
                        SpartanMoneyDisplaySettings.border = nil;
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Border Hidden");

                elseif(command == "showborder") then
                        SpartanMoneyDisplaySettings.border = 1;
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Border Shown");

                elseif(command == "cashflow") then
                        local SMDCF = "Enabled";
                        if (SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].on) then
                          SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].cash = GetMoney();
                          SMDCF = "Reset";
                        else
                          if (SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].cash == nil) then
                            SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].cash = GetMoney();
                          end;
                        end;
                        SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].on = true;
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Cashflow "..SMDCF);

                elseif(command == "cashflow off") then
                        SpartanMoneyDisplaySettings.cashflow[SpartanMoneyDisplay_PlayerName].on = false;
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Cashflow Disabled");

                elseif(string.find(command, "alpha") ~= nul) then
                        local i, j = string.find(command, "%d+");
                        if (i ~= nil) then
                                SpartanMoneyDisplay_Alpha(tonumber(string.sub(command, i, j), 10));
                        end
                        SpartanMoneyDisplay_Update();
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Alpha Set");

                else
                        DEFAULT_CHAT_FRAME:AddMessage(" ");
                        DEFAULT_CHAT_FRAME:AddMessage(" ");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00SpartanMoneyDisplay Command List");
                        DEFAULT_CHAT_FRAME:AddMessage(" ");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney reset - Reset all defaults");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney show - Shows the mod");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney hide - Hides the mod");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney lock - Locks the mod");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney unlock - Unlocks the mod");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney cashflow [off] - Enables/Resets/Disables cashflow mode");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney hideborder - Hides window border");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney showborder - Shows window border");
                        DEFAULT_CHAT_FRAME:AddMessage("|cffffff00/Spartanmoney alpha 0-255 - Set bg transparency (0 = transparent, 255 = solid)");
                end
        end

        SMD_Frame:ClearAllPoints();
        SMD_Frame:SetPoint("BOTTOMLEFT", "UIParent", "BOTTOMLEFT", SpartanMoneyDisplaySettings.dispX, SpartanMoneyDisplaySettings.dispY);

end

function SpartanMoneyDisplay_Alpha(iAlpha)
        if (iAlpha >= 0 and iAlpha <= 255) then
                SpartanMoneyDisplaySettings.alpha = iAlpha;
        end
end

--------------------
-- Update Function
--------------------

function SpartanMoneyDisplay_Update()

        -- Apply the display settings
        if(SpartanMoneyDisplaySettings) then
                if(SpartanMoneyDisplaySettings.on) then
                        SMD_Frame:Show();
                else
                        SMD_Frame:Hide();
                end

                if (SpartanMoneyDisplaySettings.border) then
                        SMD_Frame:SetBackdropBorderColor(TOOLTIP_DEFAULT_COLOR.r, TOOLTIP_DEFAULT_COLOR.g, TOOLTIP_DEFAULT_COLOR.b, 1.0);
                else
                        SMD_Frame:SetBackdropBorderColor(0.0, 0.0, 0.0, 0.0);
                end

                if (SpartanMoneyDisplaySettings.alpha) then
                        SMD_Frame:SetBackdropColor(TOOLTIP_DEFAULT_BACKGROUND_COLOR.r, TOOLTIP_DEFAULT_BACKGROUND_COLOR.g, TOOLTIP_DEFAULT_BACKGROUND_COLOR.b, SpartanMoneyDisplaySettings.alpha / 255);
                else
                        SMD_Frame:SetBackdropColor(TOOLTIP_DEFAULT_BACKGROUND_COLOR.r, TOOLTIP_DEFAULT_BACKGROUND_COLOR.g, TOOLTIP_DEFAULT_BACKGROUND_COLOR.b, 1);
                end

                SMD_Frame:SetHeight(26);
                SMD_Frame:SetWidth(155);

        end
end

function SMD_SavePosition()
    SpartanMoneyDisplaySettings.dispX = this:GetLeft();
    SpartanMoneyDisplaySettings.dispY = this:GetBottom();
end

function SMD_Locked()
    return SpartanMoneyDisplaySettings.locked;
end
